diff --git a/1.6/1.6/Assemblies/ArachnaeSwarm.dll b/1.6/1.6/Assemblies/ArachnaeSwarm.dll
index 7324a26..7356c77 100644
Binary files a/1.6/1.6/Assemblies/ArachnaeSwarm.dll and b/1.6/1.6/Assemblies/ArachnaeSwarm.dll differ
diff --git a/1.6/1.6/Defs/ResearchProjectDefs/ARA_ResearchProjects.xml b/1.6/1.6/Defs/ResearchProjectDefs/ARA_ResearchProjects.xml
index 9fb4fcd..e375b4f 100644
--- a/1.6/1.6/Defs/ResearchProjectDefs/ARA_ResearchProjects.xml
+++ b/1.6/1.6/Defs/ResearchProjectDefs/ARA_ResearchProjects.xml
@@ -10,7 +10,7 @@
ARA_ResearchTab
1
0
- 1
+ 2500
ARA_Technology_5ESS
diff --git a/1.6/1.6/Defs/ThingDef_Races/ARA_RaceNodeSwarm.xml b/1.6/1.6/Defs/ThingDef_Races/ARA_RaceNodeSwarm.xml
index 327ad45..d911556 100644
--- a/1.6/1.6/Defs/ThingDef_Races/ARA_RaceNodeSwarm.xml
+++ b/1.6/1.6/Defs/ThingDef_Races/ARA_RaceNodeSwarm.xml
@@ -692,6 +692,7 @@
+ ARA_RW_Large_Arc_Gun
ARA_RW_Acid_Mortar
ARA_RW_Basic_SniperCannon_Gun
ARA_RW_Basic_FireSpewer_Gun
diff --git a/1.6/1.6/Defs/Thing_Misc/ARA_Things_Items.xml b/1.6/1.6/Defs/Thing_Misc/ARA_Things_Items.xml
index 146df9e..058544b 100644
--- a/1.6/1.6/Defs/Thing_Misc/ARA_Things_Items.xml
+++ b/1.6/1.6/Defs/Thing_Misc/ARA_Things_Items.xml
@@ -152,7 +152,7 @@
false
30
- 120
+ 100
50
0.01
@@ -182,7 +182,7 @@
false
30
- 120
+ 20
10
0.01
diff --git a/1.6/1.6/Defs/Thing_Misc/Weapons/ARA_Weapon.xml b/1.6/1.6/Defs/Thing_Misc/Weapons/ARA_Weapon.xml
index 4c64d47..816898f 100644
--- a/1.6/1.6/Defs/Thing_Misc/Weapons/ARA_Weapon.xml
+++ b/1.6/1.6/Defs/Thing_Misc/Weapons/ARA_Weapon.xml
@@ -33,7 +33,7 @@
50
- 100
+ 300
1000
5
25
@@ -45,7 +45,7 @@
Cut
- 10
+ 12
1.3
0.50
@@ -54,7 +54,7 @@
Poke
- 8
+ 10
0.20
1.5
@@ -197,7 +197,7 @@
350
- 1000
+ 3000
5
350
12
@@ -279,7 +279,7 @@
UnfinishedWeapon
- 300
+ 200
1300
0.5
@@ -391,7 +391,7 @@
UnfinishedWeapon
- 600
+ 1000
1300
4
@@ -408,7 +408,7 @@
ArachnaeSwarm.Verb_ShootWithOffset
true
false
- 0.8
+ 0.5
Bullet_ARA_RW_Toxic_Needle_MG
25.9
48
@@ -489,7 +489,7 @@
UnfinishedWeapon
- 600
+ 650
1300
4
@@ -605,7 +605,7 @@
UnfinishedWeapon
- 1500
+ 2000
1300
3.5
@@ -721,7 +721,7 @@
UnfinishedWeapon
- 1500
+ 1400
1300
3.5
@@ -949,16 +949,16 @@
true
1.5
16
- 12
+ 8
3
Shot_MiniFlameblaster
GunTail_Medium
9
- 15
+ 45
ARA_AcidBurn
- 12
+ 15
Filth_SpentAcid
ARA_Fire_Spew
0.5
@@ -1085,7 +1085,7 @@
UnfinishedWeapon
- 2500
+ 2200
1300
3.5
@@ -1165,7 +1165,7 @@
ARA_AcidBurn
15
20
- 45
+ 30
1
3.5
true
@@ -1287,7 +1287,7 @@
60
ARA_AcidBurn
- 5
+ 15
Filth_SpentAcid
2
true
@@ -1342,7 +1342,7 @@
UnfinishedWeapon
- 2500
+ 2200
1300
4
@@ -1423,7 +1423,7 @@
60
ARA_AcidBurn
- 3
+ 6
Filth_SpentAcid
2
true
@@ -1477,7 +1477,7 @@
UnfinishedWeapon
- 700
+ 1600
1300
3.5
@@ -1588,120 +1588,17 @@
-
- ARA_RW_Arc_Gun
-
- 阿拉克涅虫群督虫使用的远程武装器官,通过从携带大量电荷的细胞中释放能量,虫群可以使用这种武装器官在敌人的集群中发起连锁闪电打击。
- Normal
- Animal
-
- ARA_Cocoon_Weapon_1Stage
-
-
- ArachnaeSwarm/Weapon/ARA_RW_Basic_SkyHive_Gun
- Graphic_Single
- 1.2
-
- 0.8
- SpitterSpawn
-
-
- ARA_Technology_1THD
- UnfinishedWeapon
-
-
- 2500
- 1300
-
- 3.5
- 0.5
- 0.6
- 0.45
- 0.3
- 2.5
- 160
- 7
-
-
-
- ArachnaeSwarm.Verb_ShootBeamArc
-
-
- true
- 0
- 18
- 6
- 10
- ARA_Psi_Damage
- 20
-
-
- 0
- BeamGraser_Shooting
- Fleck_BeamBurn
- 0.32
- ARA_Arc_Beam_Mote
- GraserBeam_End
-
-
- 0.6
- 0.6
- 0.25
-
-
-
- true
-
-
-
- 6
- 18
- 0.7
- ARA_Arc_Beam_Mote
-
-
-
- 50
-
-
- ARA_Armed_Organ
- ARA_Armed_Organ_Ranged
- ARA_Armed_Organ_T2
- ARA_Armed_Organ_Small_Ranged_Energy
-
- 0.01
- None
-
-
-
-
-
- ARA_Weapon_Damage_LightingChain
-
-
- 1
- 1
-
-
-
-
ARA_RW_Large_Arc_Gun
-
- 阿拉克涅虫群督虫使用的大型远程武装器官,发射可分裂的传导性闪电链。电死你电死你电死你。
+
+ 阿拉克涅虫群督虫使用的大型远程武装器官,通过从携带大量电荷的细胞中释放能量,虫群可以使用这种武装器官在敌人的集群中发起连锁闪电打击。
Normal
Animal
ARA_Cocoon_Weapon_1Stage
- ArachnaeSwarm/Weapon/ARA_RW_Basic_SkyHive_Gun
+ ArachnaeSwarm/Weapon/ARA_RW_Large_Arc_Gun
Graphic_Single
1.2
@@ -1789,11 +1686,12 @@
+ ARA_Huge_Weapon
ARA_Weapon_Damage_LightingChain
- 1
- 1
+ 2
+ 2
diff --git a/1.6/1.6/Defs/Thing_building/ARA_NutrientNetworkBuilding.xml b/1.6/1.6/Defs/Thing_building/ARA_NutrientNetworkBuilding.xml
index 53963e8..13caa1c 100644
--- a/1.6/1.6/Defs/Thing_building/ARA_NutrientNetworkBuilding.xml
+++ b/1.6/1.6/Defs/Thing_building/ARA_NutrientNetworkBuilding.xml
@@ -735,34 +735,13 @@
InsectJelly
- 20
+ 10
0
true
true
true
-
- 虫蜜
- 虫蜜
-
- 100.0
- 0
- true
- 0
- false
- false
-
-
-
- ARA_InsectJelly
-
-
-
- false
- true
- true
-
200
0.25
@@ -770,12 +749,35 @@
1
+
+ 虫蜜
+ 虫蜜
+
+ 25
+ 0
+ true
+
+
+
+ ARA_InsectJelly
+
+
+
+ false
+ false
+ false
+ false
+ false
+ true
+
+
-
- CompRefuelable
-
+ 60
0.99
+ true
+ true
+ false
diff --git a/Content/Textures/ArachnaeSwarm/Weapon/ARA_RW_Large_Arc_Gun.png b/Content/Textures/ArachnaeSwarm/Weapon/ARA_RW_Large_Arc_Gun.png
new file mode 100644
index 0000000..5181d39
Binary files /dev/null and b/Content/Textures/ArachnaeSwarm/Weapon/ARA_RW_Large_Arc_Gun.png differ
diff --git a/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/.suo b/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/.suo
index 7cb8042..580f2ce 100644
Binary files a/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/.suo and b/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/.suo differ
diff --git a/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/DocumentLayout.json b/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/DocumentLayout.json
index 7fcebad..01c89df 100644
--- a/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/DocumentLayout.json
+++ b/Source/ArachnaeSwarm/.vs/ArachnaeSwarm/v17/DocumentLayout.json
@@ -1,13 +1,17 @@
{
"Version": 1,
- "WorkspaceRootPath": "D:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\",
+ "WorkspaceRootPath": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\",
"Documents": [
{
- "AbsoluteMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|d:\\steamlibrary\\steamapps\\common\\rimworld\\mods\\arachnaeswarm\\source\\arachnaeswarm\\building_comps\\ara_compinteractiveproducer\\compinteractiveproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
+ "AbsoluteMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|e:\\steamlibrary\\steamapps\\common\\rimworld\\mods\\arachnaeswarm\\source\\arachnaeswarm\\building_comps\\compnutritiontofuelconverter.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
+ "RelativeMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|solutionrelative:building_comps\\compnutritiontofuelconverter.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
+ },
+ {
+ "AbsoluteMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|e:\\steamlibrary\\steamapps\\common\\rimworld\\mods\\arachnaeswarm\\source\\arachnaeswarm\\building_comps\\ara_compinteractiveproducer\\compinteractiveproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
"RelativeMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|solutionrelative:building_comps\\ara_compinteractiveproducer\\compinteractiveproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
},
{
- "AbsoluteMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|d:\\steamlibrary\\steamapps\\common\\rimworld\\mods\\arachnaeswarm\\source\\arachnaeswarm\\building_comps\\ara_compinteractiveproducer\\compresearchproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
+ "AbsoluteMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\building_comps\\ara_compinteractiveproducer\\compresearchproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
"RelativeMoniker": "D:0:0:{EAE0DB6B-E282-C812-7F5A-6D13E9D24581}|ArachnaeSwarm.csproj|solutionrelative:building_comps\\ara_compinteractiveproducer\\compresearchproducer.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
}
],
@@ -18,21 +22,8 @@
"DocumentGroups": [
{
"DockedWidth": 200,
- "SelectedChildIndex": 2,
+ "SelectedChildIndex": 1,
"Children": [
- {
- "$type": "Document",
- "DocumentIndex": 1,
- "Title": "CompResearchProducer.cs",
- "DocumentMoniker": "D:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
- "RelativeDocumentMoniker": "Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
- "ToolTip": "D:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
- "RelativeToolTip": "Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
- "ViewState": "AgIAADoBAAAAAAAAAAAkwFIBAAAmAAAAAAAAAA==",
- "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
- "WhenOpened": "2025-10-17T09:09:18.518Z",
- "EditorCaption": ""
- },
{
"$type": "Bookmark",
"Name": "ST:0:0:{1c4feeaa-4718-4aa9-859d-94ce25d182ba}"
@@ -40,12 +31,37 @@
{
"$type": "Document",
"DocumentIndex": 0,
+ "Title": "CompNutritionToFuelConverter.cs",
+ "DocumentMoniker": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\CompNutritionToFuelConverter.cs",
+ "RelativeDocumentMoniker": "Building_Comps\\CompNutritionToFuelConverter.cs",
+ "ToolTip": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\CompNutritionToFuelConverter.cs",
+ "RelativeToolTip": "Building_Comps\\CompNutritionToFuelConverter.cs",
+ "ViewState": "AgIAAAAAAAAAAAAAAAAAAKEAAAAcAAAAAAAAAA==",
+ "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
+ "WhenOpened": "2025-10-17T11:32:00.484Z",
+ "EditorCaption": ""
+ },
+ {
+ "$type": "Document",
+ "DocumentIndex": 2,
+ "Title": "CompResearchProducer.cs",
+ "DocumentMoniker": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
+ "RelativeDocumentMoniker": "Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
+ "ToolTip": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
+ "RelativeToolTip": "Building_Comps\\ARA_CompInteractiveProducer\\CompResearchProducer.cs",
+ "ViewState": "AgIAADoBAAAAAAAAAAAkwFIBAAAmAAAAAAAAAA==",
+ "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
+ "WhenOpened": "2025-10-17T09:09:18.518Z"
+ },
+ {
+ "$type": "Document",
+ "DocumentIndex": 1,
"Title": "CompInteractiveProducer.cs",
- "DocumentMoniker": "D:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
+ "DocumentMoniker": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
"RelativeDocumentMoniker": "Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
- "ToolTip": "D:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
+ "ToolTip": "E:\\SteamLibrary\\steamapps\\common\\RimWorld\\Mods\\ArachnaeSwarm\\Source\\ArachnaeSwarm\\Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
"RelativeToolTip": "Building_Comps\\ARA_CompInteractiveProducer\\CompInteractiveProducer.cs",
- "ViewState": "AgIAAJMBAAAAAAAAAAAUwNcBAAAyAAAAAAAAAA==",
+ "ViewState": "AgIAAJYBAAAAAAAAAAAUwKoBAAAAAAAAAAAAAA==",
"Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
"WhenOpened": "2025-10-17T09:00:51.526Z",
"EditorCaption": ""
diff --git a/Source/ArachnaeSwarm/Building_Comps/CompNutritionToFuelConverter.cs b/Source/ArachnaeSwarm/Building_Comps/CompNutritionToFuelConverter.cs
index 1a60889..0f30246 100644
--- a/Source/ArachnaeSwarm/Building_Comps/CompNutritionToFuelConverter.cs
+++ b/Source/ArachnaeSwarm/Building_Comps/CompNutritionToFuelConverter.cs
@@ -1,4 +1,5 @@
using RimWorld;
+using System.Collections.Generic;
using Verse;
namespace ArachnaeSwarm
@@ -19,7 +20,7 @@ namespace ArachnaeSwarm
public class CompNutritionToFuelConverter : ThingComp
{
private CompRefuelableNutrition nutritionComp;
- private CompRefuelable fuelComp;
+ private CompProductStorage productStorageComp; // 改为使用 CompProductStorage
public float nutritionProgress = 0f;
public float workProgress = 0f;
@@ -30,15 +31,15 @@ namespace ArachnaeSwarm
{
base.PostSpawnSetup(respawningAfterLoad);
nutritionComp = parent.GetComp();
- fuelComp = parent.GetComp();
+ productStorageComp = parent.GetComp(); // 改为获取 CompProductStorage
if (nutritionComp == null)
{
Log.Error($"[ArachnaeSwarm] {parent.def.defName} has CompNutritionToFuelConverter but no CompRefuelableNutrition.");
}
- if (fuelComp == null)
+ if (productStorageComp == null)
{
- Log.Error($"[ArachnaeSwarm] {parent.def.defName} has CompNutritionToFuelConverter but no CompRefuelable.");
+ Log.Error($"[ArachnaeSwarm] {parent.def.defName} has CompNutritionToFuelConverter but no CompProductStorage.");
}
}
@@ -60,7 +61,7 @@ namespace ArachnaeSwarm
private void TryProcess()
{
- if (fuelComp == null || fuelComp.IsFull)
+ if (productStorageComp == null || productStorageComp.IsFull)
{
return;
}
@@ -88,27 +89,37 @@ namespace ArachnaeSwarm
{
int unitsToCraft = (int)(workProgress / Props.workAmount);
float fuelToProduce = unitsToCraft * Props.fuelAmount;
- float spaceInTank = fuelComp.Props.fuelCapacity - fuelComp.Fuel;
+ float spaceInStorage = productStorageComp.StorageSpaceRemaining;
- if (spaceInTank > 0)
+ if (spaceInStorage > 0)
{
- // Add as much fuel as possible, up to what was produced.
- float fuelToAdd = System.Math.Min(fuelToProduce, spaceInTank);
- fuelComp.Refuel(fuelToAdd);
-
- // Consume the full cost, regardless of how much was actually added.
- nutritionProgress -= unitsToCraft * Props.nutritionCost;
- workProgress -= unitsToCraft * Props.workAmount;
+ // 使用 CompProductStorage 的 API 添加产物
+ float fuelToAdd = System.Math.Min(fuelToProduce, spaceInStorage);
+ bool added = productStorageComp.TryAddProduct(fuelToAdd);
+
+ if (added)
+ {
+ // Consume the full cost, regardless of how much was actually added.
+ nutritionProgress -= unitsToCraft * Props.nutritionCost;
+ workProgress -= unitsToCraft * Props.workAmount;
+
+ // 记录日志用于调试
+ Log.Message($"[NutritionToFuel] Added {fuelToAdd} fuel to storage. Remaining space: {productStorageComp.StorageSpaceRemaining}");
+ }
+ else
+ {
+ Log.Warning($"[NutritionToFuel] Failed to add fuel to storage. Requested: {fuelToAdd}, Space: {spaceInStorage}");
+ }
}
// If spaceInTank is 0, do nothing and let progress build up.
}
}
public override string CompInspectStringExtra()
{
- if (fuelComp == null) return null;
+ if (productStorageComp == null) return null;
- if (fuelComp.IsFull)
+ if (productStorageComp.IsFull)
{
return "ARA_NutritionConverter_State_TankFull".Translate();
}
@@ -120,5 +131,46 @@ namespace ArachnaeSwarm
return "ARA_NutritionConverter_Working".Translate(workProgress.ToString("F0"), Props.workAmount);
}
+
+ // 新增:调试命令
+ public override IEnumerable CompGetGizmosExtra()
+ {
+ foreach (var gizmo in base.CompGetGizmosExtra())
+ {
+ yield return gizmo;
+ }
+
+ if (DebugSettings.ShowDevGizmos)
+ {
+ // 调试命令:显示状态信息
+ yield return new Command_Action
+ {
+ defaultLabel = "DEV: Show Converter Status",
+ action = delegate
+ {
+ string status = $"Nutrition Converter Status:\n" +
+ $"Nutrition Progress: {nutritionProgress:F1}/{Props.nutritionCost}\n" +
+ $"Work Progress: {workProgress:F0}/{Props.workAmount}\n" +
+ $"Product Storage: {productStorageComp?.StorageAmount:F1}/{productStorageComp?.StorageCapacity:F1}\n" +
+ $"Nutrition Comp: {(nutritionComp != null ? "Found" : "Missing")}\n" +
+ $"Product Storage Comp: {(productStorageComp != null ? "Found" : "Missing")}";
+ Messages.Message(status, MessageTypeDefOf.SilentInput);
+ Log.Message(status);
+ }
+ };
+
+ // 调试命令:重置进度
+ yield return new Command_Action
+ {
+ defaultLabel = "DEV: Reset Progress",
+ action = delegate
+ {
+ nutritionProgress = 0f;
+ workProgress = 0f;
+ Messages.Message("Converter progress reset", MessageTypeDefOf.SilentInput);
+ }
+ };
+ }
+ }
}
-}
\ No newline at end of file
+}
@@ -88,27 +89,37 @@ namespace ArachnaeSwarm
}
- // If spaceInTank is 0, do nothing and let progress build up.
+ // If spaceInStorage is 0, do nothing and let progress build up.
}
}
diff --git a/非公开资源/Content/Textures/Apperal/ARA_SpiderOne_PowerArmor_Thin_south.sai2 b/非公开资源/Content/Textures/Apperal/ARA_SpiderOne_PowerArmor_Thin_south.sai2
index dc3ee59..645ec12 100644
Binary files a/非公开资源/Content/Textures/Apperal/ARA_SpiderOne_PowerArmor_Thin_south.sai2 and b/非公开资源/Content/Textures/Apperal/ARA_SpiderOne_PowerArmor_Thin_south.sai2 differ
diff --git a/非公开资源/Content/Textures/Weapon/ARA_RW_Large_Arc_Gun.sai2 b/非公开资源/Content/Textures/Weapon/ARA_RW_Large_Arc_Gun.sai2
new file mode 100644
index 0000000..faae13d
Binary files /dev/null and b/非公开资源/Content/Textures/Weapon/ARA_RW_Large_Arc_Gun.sai2 differ